==> mirascope-1.0.2.tar.gz: mirascope-1.0.2/docs/cookbook/agents/index.md <==
# Agents

This collection of recipes explores the powerful concept of AI agents and how they can be implemented using Mirascope.

## What are AI Agents?

AI agents are autonomous or semi-autonomous software entities that can perceive their environment, make decisions, and take actions to achieve specific goals. In the context of Large Language Models (LLMs), agents can be thought of as LLMs enhanced with additional capabilities such as memory, tool use, and multi-step reasoning.

## Why Use Agents?

Agents offer several advantages over simple LLM calls:

1. **Complex Task Handling**: Agents can break down and tackle multi-step problems.
2. **Persistence**: Agents can maintain state and context over multiple interactions.
3. **Tool Integration**: Agents can leverage external tools and APIs to expand their capabilities.
4. **Adaptability**: Agents can adjust their approach based on intermediate results or changing conditions.

## Key Concepts in Agent Design

When working with agents, you'll encounter several important concepts:

- **Memory**: How agents store and recall information across interactions.
- **Planning**: The agent's ability to formulate a sequence of actions to achieve a goal.
- **Tool Use**: Integration and utilization of external functions or APIs.
- **Reasoning**: The process by which agents make decisions and draw conclusions.

## Recipes in this Section

Explore the following recipes to learn how to build and use agents with Mirascope:

1. [Web Search Agent](./web_search_agent.md): Implement an agent that performs web searches and answers questions.
2. [Blog Writing Agent](./blog_writing_agent.md): Create an agent that researches topics and writes blog posts.
3. [SQL Agent](./generating_sql_agent.md): Create an agent that generates and executes SQL queries based on natural language input.
4. [Localized Agent](./localized_agent.md): Build an agent that provides location-specific information and recommendations.
5. [Local Chat with Codebase](./local_chat_with_codebase.md): Develop an agent that can answer questions about a local codebase.

Each recipe demonstrates different aspects of agent design and implementation, providing you with a comprehensive toolkit for building sophisticated AI agents using Mirascope.

Happy coding!

==> mirascope-1.2.1.tar.gz: mirascope-1.2.1/docs/cookbook/agents/index.md <==
# Agents

This collection of recipes explores the powerful concept of AI agents and how they can be implemented using Mirascope.

## What are AI Agents?

AI agents are autonomous or semi-autonomous software entities that can perceive their environment, make decisions, and take actions to achieve specific goals. In the context of Large Language Models (LLMs), agents can be thought of as LLMs enhanced with additional capabilities such as memory, tool use, and multi-step reasoning.

## Why Use Agents?

Agents offer several advantages over simple LLM calls:

1. **Complex Task Handling**: Agents can break down and tackle multi-step problems.
2. **Persistence**: Agents can maintain state and context over multiple interactions.
3. **Tool Integration**: Agents can leverage external tools and APIs to expand their capabilities.
4. **Adaptability**: Agents can adjust their approach based on intermediate results or changing conditions.

## Key Concepts in Agent Design

When working with agents, you'll encounter several important concepts:

- **Memory**: How agents store and recall information across interactions.
- **Planning**: The agent's ability to formulate a sequence of actions to achieve a goal.
- **Tool Use**: Integration and utilization of external functions or APIs.
- **Reasoning**: The process by which agents make decisions and draw conclusions.

## Recipes in this Section

Explore the following recipes to learn how to build and use agents with Mirascope:

1. [Web Search Agent](./web_search_agent.md): Implement an agent that performs web searches and answers questions.
2. [Blog Writing Agent](./blog_writing_agent.md): Create an agent that researches topics and writes blog posts.
3. [SQL Agent](./sql_agent.md): Create an agent that generates and executes SQL queries based on natural language input.
4. [Localized Agent](./localized_agent.md): Build an agent that provides location-specific information and recommendations.
5. [Local Chat with Codebase](./local_chat_with_codebase.md): Develop an agent that can answer questions about a local codebase.

Each recipe demonstrates different aspects of agent design and implementation, providing you with a comprehensive toolkit for building sophisticated AI agents using Mirascope.

Happy coding!
